#ifndef CAMWIRE2_CAMWIRE_CAMWIRE_HANDLE_H
#define CAMWIRE2_CAMWIRE_CAMWIRE_HANDLE_H
/***********************************************************************

    Copyright (c) Johann Schoonees 2004-2015

    This file is part of Camwire, a generic camera interface.

    Camwire is free software; you can redistribute it and/or modify it
    under the terms of the GNU Lesser General Public License as
    published by the Free Software Foundation; either version 2.1 of the
    License, or (at your option) any later version.

    Camwire is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with Camwire; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA


    Title: Camwire handle definition

    Description: Header file to provide the definition of the Camwire
    handle struct.

    This header would not be needed for normal use of the Camwire
    library.  It should only be included in user code that wishes to
    access dc1394 functions directly.

***********************************************************************/


#include <dc1394/camera.h>  /* dc1394camera_t.*/

/* Set up for C function definitions, even when using C++ */
#ifdef __cplusplus
extern "C" {
#endif


/* Below is the type definition of the camwire handle structure.  The
   camwire handle itself is typedefed as a pointer to this structure.

   The user need not know this structure nor should anyone use its
   members directly.  The camwire_bus_get_... functions defined in this
   module provide efficient maintainable access.

   The camera member is needed by many libdc1394 functions.  It is a
   handle to the current IEEE 1394 camera connected to an OHCI port and
   node.

   The userdata member provides a way for a user (in our case this is
   the Camwire main module) to associate private data with the camwire
   handle, such as status information.  A pointer to the user data
   structure can be stored in userdata by the camwire_bus_set_userdata()
   function, without this module needing to know the user data structure
   definition.  */

typedef dc1394camera_t *           Camera_handle;
typedef struct camwire_user_data * User_handle;

typedef struct camwire_bus_handle
{
    Camera_handle camera;
    User_handle userdata;
}
Camwire_bus_handle;

typedef Camwire_bus_handle * Camwire_handle;
/* This is the Camwire handle type. */


Camera_handle camwire_handle_get_camera(const Camwire_handle c_handle);
/* Returns the dc1394camera_t camera handle for the given camwire
   handle.  Needed by many dc1394 functions in Camwire. */

User_handle camwire_bus_get_userdata(const Camwire_handle c_handle);
/* Returns a pointer to the user data structure for the given camwire
   handle.  Needed for internal status maintenance in Camwire. */

int camwire_bus_set_userdata(const Camwire_handle c_handle, User_handle user_data);
/* Registers a pointer to a user data structure for the given camwire
   handle.  Returns 1 on success and 0 if the handle does not exist or
   if the pointer is already in use.  Needed for internal status
   maintenance in Camwire. */

    
#ifdef __cplusplus
}
#endif

#endif /* ndef CAMWIRE2_CAMWIRE_CAMWIRE_HANDLE_H */
